Learn R Programming

iCARH (version 2.0.2.1)

iCARH.getPathwaysMat: Builds pathways adjacency matrices

Description

Builds pathways adjacency matrices from specified KEGG identifiers. Returns a list of pathway adjacency matrices based on shortest paths.

Usage

iCARH.getPathwaysMat(keggid, org)

Arguments

keggid

KEGG identifiers as specified in KEGG. keggid is list that might contain multiple identifiers per metabolite.

org

organism

Value

list of pathway matrices based on shortest paths between two metabolites

Examples

Run this code
# NOT RUN {
keggid = list("C08363")
iCARH.getPathwaysMat(keggid, "rno")
gc()
# }
# NOT RUN {
keggid = list("Unk1", "C00350",c("C08363", "C01245"))
iCARH.getPathwaysMat(keggid, "rno")
gc()
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab